package cn.wisenergy.chnmuseum.party.common.dfs;

import com.github.tobato.fastdfs.domain.fdfs.StorePath;
import com.github.tobato.fastdfs.domain.fdfs.ThumbImageConfig;
import com.github.tobato.fastdfs.domain.proto.storage.DownloadByteArray;
import com.github.tobato.fastdfs.service.FastFileStorageClient;
import org.apache.commons.io.FilenameUtils;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;

@Component
public class FdfsUtil {

    @Resource
    private FastFileStorageClient fastFileStorageClient;

    @Resource
    private ThumbImageConfig thumbImageConfig;

    /**
     * 上传文件
     *
     * @param file 文件对象
     * @return storePath 文件在服务器中的存储路径 group1/M00/00/08/rBEAA2A_Ci2AU9pHAAYlnPgRYiA554.jpg
     * @throws IOException
     */
    public String uploadFile(MultipartFile file) throws IOException {
//        StorePath storePath = fastFileStorageClient.uploadFile("aifruit", //默认都是放在aifruit分组group
        StorePath storePath = fastFileStorageClient.uploadFile(file.getInputStream(),
                file.getSize(),
                FilenameUtils.getExtension(file.getOriginalFilename()), null);
        return storePath.getFullPath(); //返回完整的图片存放路径(含group)
    }

    /**
     * 下载文件(文件字节)
     *
     * @param fileUrl 文件服务器存储路径 group1/M00/00/08/rBEAA2A_Ci2AU9pHAAYlnPgRYiA554.jpg
     * @return byte[] 文件字节
     * @throws IOException
     */
    public byte[] downloadFileByByte(String fileUrl) {
        String group = fileUrl.substring(0, fileUrl.indexOf("/"));
        String path = fileUrl.substring(fileUrl.indexOf("/") + 1);
        return fastFileStorageClient.downloadFile(group, path, new DownloadByteArray());
    }

}
